'use strict';

var _reducer = require('./reducer');

var _reducer2 = _interopRequireDefault(_reducer);

var _initialState = require('./initialState');

var _initialState2 = _interopRequireDefault(_initialState);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('i18n reducer', function () {
    it('should return the initial state', function () {
        expect((0, _reducer2.default)(undefined, {})).toEqual(_initialState2.default);
    });

    it('should handle SET_CURRENT', function () {
        var newState = Object.assign({}, _initialState2.default);
        newState.currentLanguage = 'en-US';
        expect((0, _reducer2.default)(_initialState2.default, {
            type: 'SET_CURRENT',
            data: 'en-US'
        })).toEqual(newState);
    });

    it('should handle SET_LANGUAGES', function () {

        var newState = Object.assign({}, _initialState2.default);
        newState.languages = [{
            code: 'car-CAR',
            name: 'Птичий'
        }, {
            code: 'en-US',
            name: 'English (USA)'
        }];
        expect((0, _reducer2.default)(_initialState2.default, {
            type: 'SET_LANGUAGES',
            data: [{
                code: 'car-CAR',
                name: 'Птичий'
            }, {
                code: 'en-US',
                name: 'English (USA)'
            }]
        })).toEqual(newState);
    });

    it('should handle SET_DICTIONARIES', function () {

        var newState = Object.assign({}, _initialState2.default);
        newState.dictionaries = {
            'car-CAR': {
                'key_1': 'Первый дефолтный ключ птичьего языка для теста',
                'key_2': ['$Count', ' ', ['птичка', 'птички', 'птичек']]
            },
            'en-US': {
                'key_1': 'First default key',
                'key_2': ['$Count', ' ', ['thing', 'things']]
            }
        };
        expect((0, _reducer2.default)(_initialState2.default, {
            type: 'SET_DICTIONARIES',
            data: {
                'car-CAR': {
                    'key_1': 'Первый дефолтный ключ птичьего языка для теста',
                    'key_2': ['$Count', ' ', ['птичка', 'птички', 'птичек']]
                },
                'en-US': {
                    'key_1': 'First default key',
                    'key_2': ['$Count', ' ', ['thing', 'things']]
                }
            }
        })).toEqual(newState);
    });

    it('should handle ADD_DICTIONARY', function () {

        var newState = Object.assign({}, _initialState2.default);
        newState.dictionaries['new-NEW'] = {
            'new_key_1': 'First new default key',
            'new_key_2': ['$Count new', ' ', ['thing', 'things']]
        };

        expect((0, _reducer2.default)(_initialState2.default, {
            type: 'ADD_DICTIONARY',
            data: {
                languageCode: 'new-NEW',
                dictionary: {
                    'new_key_1': 'First new default key',
                    'new_key_2': ['$Count new', ' ', ['thing', 'things']]
                }
            }
        })).toEqual(newState);
    });
});